@@ -75,7 +75,7 @@ sub withecho {
 }
 
 ## 
-# Same as withecho but does not show to control prompt on errors
+# Same as withecho but does not show the control prompt on errors
 # returns on success
 sub withechoNoPrompt {
    # weed undefs out
@@ -373,9 +373,19 @@ line and let svn-descripts redetect the value. Also check the associated URL.
 
 sub check_uncommited {
    open($svn, "svn status |");
-   @conflicts = <$svn>;
-   if ($#conflicts != -1) {
-      print "E: found unresolved issues: \n\n @conflicts\n";
+   @statuslist = <$svn>;
+   for(@statuslist) {
+       if(/^\s*M+\s+(.*)/) {
+           # FIXME: rewrite to run svn propget in one command with a list if
+           # somebody complains about performance issues
+           push(@conflicts,$_) if not `svn propget deb:ignoreM "$1"`;
+       }
+       else {
+           push(@conflicts, $_);
+       }
+   }
+   if (@conflicts) {
+      print "E: found unresolved issues: \n\n@conflicts\n";
       exwerror "E: Resolve them manually before continueing\n";
    }
    close($svn);
